@@ -5,7 +5,7 @@ use base qw(HTML::FormFu::Filter);
 
 use Encode qw(encode decode FB_CROAK);
 
-__PACKAGE__->mk_accessors($_) for qw(_candidates encode_to);
+__PACKAGE__->mk_item_accessors($_) for qw(_candidates encode_to);
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -14,33 +14,36 @@ sub filter {
 
     my $utf8 = $self->decode_to_utf8($value);
 
-    if ( !defined $utf8 ) {
-        die
-            "HTML::FormFu::Filter::Encode: Unable to decode given string to utf8.";
-    }
+    die "HTML::FormFu::Filter::Encode: Unable to decode given string to utf8"
+        if !defined $utf8;
 
     return $self->encode_from_utf8($utf8);
 }
 
 sub get_candidates {
-    my $self = shift;
+    my ($self) = @_;
+    
     my $ret  = $self->_candidates;
+    
     if ( $ret && wantarray ) {
         return @$ret;
     }
+    
     return $ret;
 }
 
 sub candidates {
-    my $self = shift;
-    if (@_) {
-        if ( ref $_[0] && ref $_[0] eq 'ARRAY' ) {
-            $self->_candidates( $_[0] );
+    my ( $self, @candidates ) = @_;
+    
+    if ( @_ > 1 ) {
+        if ( ref $candidates[0] eq 'ARRAY' ) {
+            $self->_candidates( $candidates[0] );
         }
         else {
-            $self->_candidates( [@_] );
+            $self->_candidates( [@candidates] );
         }
     }
+    
     return $self;
 }
 
@@ -48,8 +51,10 @@ sub decode_to_utf8 {
     my ( $self, $value ) = @_;
 
     my $ret;
+    
     foreach my $candidate ( $self->get_candidates ) {
         eval { $ret = decode( $candidate, $value, FB_CROAK ) };
+        
         if ( !$@ ) {
             last;
         }
